.. _signal_analysis.entropy:

Entropy Measures
================

.. automodule:: eyetrace.signal_analysis.entropy
   :members:
   :undoc-members:
   :show-inheritance:

Entropy quantifies the regularity and complexity of a time series. This module
implements Sample Entropy (SampEn) and Approximate Entropy (ApEn), which are
widely used in physiological signal analysis.